###############################################################################
###############################################################################
##
##  Copyright (C) 2004-2008 Red Hat, Inc.  All rights reserved.
##
##  This copyrighted material is made available to anyone wishing to use,
##  modify, copy, or redistribute it subject to the terms and conditions
##  of the GNU General Public License v.2.
##
###############################################################################
###############################################################################

# main (empty) package
# http://www.rpm.org/max-rpm/s1-rpm-subpack-spec-file-changes.html

# keep around ready for later user
# %%define alphatag 2.99.02

Name: cman
Summary: CMAN - The Cluster Manager
Version: 2.03.11
Release: 1%{?alphatag:.%{alphatag}}%{?dist}
License: GPLv2+ and LGPLv2+
Group: System Environment/Base
URL: http://sources.redhat.com/cluster/wiki/
Source0: ftp://sources.redhat.com/pub/cluster/releases/cluster-%{version}.tar.gz

Requires(post): chkconfig
Requires(preun): initscripts
Requires(preun): chkconfig
Requires: openais >= 0.80.3-17 openais < 0.81
Requires: sg3_utils OpenIPMI telnet openssh-clients
Requires: pexpect net-snmp-utils pyOpenSSL

## Setup/build bits

# build support for xen
%define buildxen 0
%ifarch i386 x86_64 ia64
%define buildxen 1
%endif

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

# Build dependencies
BuildRequires: perl python
BuildRequires: glibc-kernheaders glibc-devel
BuildRequires: libxml2-devel ncurses-devel
BuildRequires: openais-devel >= 0.80.3-17 openais-devel < 0.81
%if %{buildxen}
BuildRequires: nss-devel nspr-devel libvirt-devel xen-libs
%endif

%prep
%setup -q -n cluster-%{version}

%build
# for legacy reasons, all binaries have always been installed in /sbin
./configure \
  --sbindir=/sbin \
  --initddir=%{_sysconfdir}/rc.d/init.d \
  --libdir=%{_libdir} \
%if %{buildxen}
  --enable_xen \
%endif
  --openaislibdir=%{_libdir}/openais \
  --without_gfs \
  --without_gfs2 \
  --without_gnbd \
  --without_rgmanager \
  --disable_kernel_check

##CFLAGS="$(echo '%{optflags}')" make %{_smp_mflags}
make

%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/cluster
# install logging bits
mkdir -p $RPM_BUILD_ROOT/var/log/cluster

## tree fix up
# fix library permissions or fedora strip helpers won't work.
find $RPM_BUILD_ROOT -name "lib*.so.*" -exec chmod 0755 {} \;
# fix lcrso permissions or fedora strip helpers won't work.
find $RPM_BUILD_ROOT -name "*.lcrso" -exec chmod 0755 {} \;
# fix libfence permissions
chmod 0755 $RPM_BUILD_ROOT%{_datadir}/fence/*.py
chmod 0755 $RPM_BUILD_ROOT%{_datadir}/fence/telnet_ssl
# remove docs
rm -rf $RPM_BUILD_ROOT/usr/share/doc/cluster

%clean
rm -rf $RPM_BUILD_ROOT

## Runtime and subpackages section

%description
CMAN - The Cluster Manager

%post
/sbin/chkconfig --add cman
/sbin/chkconfig --add scsi_reserve
/sbin/chkconfig --add qdiskd
/sbin/ldconfig > /dev/null

# make sure to stop cman always as last
%preun 
if [ "$1" = 0 ]; then
	/sbin/service qdiskd stop >/dev/null 2>&1
	/sbin/service scsi_reserve stop >/dev/null 2>&1
	/sbin/service cman stop >/dev/null 2>&1
	/sbin/chkconfig --del qdiskd
	/sbin/chkconfig --del scsi_reserve
	/sbin/chkconfig --del cman
fi

%postun -n cman -p /sbin/ldconfig

%files -n cman
%defattr(-,root,root,-)
%doc doc/COPYING.* doc/COPYRIGHT doc/README.licence doc/*.txt
%dir %{_sysconfdir}/cluster
%{_sysconfdir}/rc.d/init.d/cman
%{_sysconfdir}/rc.d/init.d/qdiskd
%{_sysconfdir}/rc.d/init.d/scsi_reserve
%config(noreplace) %{_sysconfdir}/udev/rules.d/*-dlm.rules
/sbin/ccs*
/sbin/cman*
/sbin/dlm*
/sbin/fence*
/sbin/gfs_controld
/sbin/group*
/sbin/*qdisk*
%{_libdir}/*.so.*
%{_datadir}/fence*
%{_datadir}/snmp/mibs/*
/usr/libexec/*
%{_mandir}/man5/*
%{_mandir}/man7/*
%{_mandir}/man8/ccs*
%{_mandir}/man8/cman*
%{_mandir}/man8/dlm*
%{_mandir}/man8/fence*
%{_mandir}/man8/gfs_controld*
%{_mandir}/man8/group*
%{_mandir}/man8/*qdisk*
%dir /var/log/cluster

%package devel
Group: Development/Libraries
Summary: CMAN - The Cluster Manager development package
Requires: cman = %{version}-%{release}

%files devel
%defattr(-,root,root,-)
%{_libdir}/*.so
%{_libdir}/*.a
%{_includedir}/*
%{_mandir}/man3/*

%description devel
CMAN - The Cluster Manager development package

%changelog
* Thu Jan 22 2009 Fabio M. Di Nitto <fdinitto@redhat.com> - 2.03.11-1
- New upstream release
  Fix several bugs and drastically improve startup errors.

* Wed Dec 10 2008 Fabio M. Di Nitto <fdinitto@redhat.com> - 2.03.10-1
- New upstream release
  Fix several bugs and port gfs1 code to match 2.6.27 kernel.

* Fri Oct 31 2008 Fabio M. Di Nitto <fdinitto@redhat.com> - 2.03.09-1
- New upstream release
  Fix rhbz#468966
  Addresses several security issues similar to CVE-2008-4192 and
  CVE-2008-4579 after deep code audit from upstream
- cleanup patches to match 2.6.26 kernel in F-9

* Tue Oct 21 2008 Fabio M. Di Nitto <fdinitto@redhat.com> - 2.03.08-1
- New upstream release
  Fix rhbz#460376 CVE-2008-4192
  Fix rhbz#467386 CVE-2008-4579
- cleanup/update patches to match 2.6.26 kernel in F-9
- add /var/log/cluster to the package

* Tue Sep 23 2008 Fabio M. Di Nitto <fdinitto@redhat.com> - 2.03.07-2
- Fix cman init script. BZ #461004

* Thu Aug 14 2008 Fabio M. Di Nitto <fdinitto@redhat.com> - 2.03.07-1
- New upstream release
- Fix rgmanager startup locking issues
- Apply patch to include kernel headers from 2.6.26 required to build
  userland. Userland will run in 2.6.25 compatibility mode
- Apply patch to keep kernel modules at 2.6.25 (upstream is at 2.6.26)
  (this patch is purely cosmetic since we don't build kernel modules
  but keep the source in sync is Good (tm))
- Cleanup packaging for installed docs and file permissions

* Mon Jul 14 2008 Fabio M. Di Nitto <fdinitto@redhat.com> - 2.03.05-1
- New upstream release
- Cleanup installed doc after upstream
- cman Requires: pyOpenSSL for new lpar fence agent
- cman Requires: pexpect and net-snmp-utils for fence agents
  Thanks to sendro on IRC for spotting the issue

* Tue Jun 10 2008 Fabio M. Di Nitto <fdinitto@redhat.com> - 2.03.04-1
- New upstream release
- Resolves: #446995 #318271 #447378 #445662
- Update license tags after major upstream cleanup
- Include COPYRIGHT file
- Add documentation
- Update Requires. Fence agents need ssh and telnet.

* Fri May 23 2008 Fabio M. Di Nitto <fdinitto@redhat.com> - 2.03.03-1
- New upstream release
- Resolves: rhbz#440770 rhbz#436240 rhbz#434905
- Add missing OpenIPMI requires to cman for fence_ipmilan
- Add missing sg3-utils requires to cman for fence_scsi
- Cleanup spec file and with it all rpmlint warnings/errors
- Drop all local patches. They have been included upstream

* Wed Mar 26 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 2.0.60-5
- Fix build for GCC 4.3

* Mon Feb 18 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 2.0.60-4
- Autorebuild for GCC 4.3

* Fri Feb 23 2007 Chris Feist <cfeist@redhat.com> - 2.0.60-2 
- Added Obsoletes for ccs, fence & dlm
- Resolves: rhbz#229822

* Tue Jan 23 2007 Chris Feist <cfeist@redhat.com> - 2.0.60-1
- fence_tool now times out after 300 seconds
- Resolves: rhbz#222933

* Tue Jan 16 2007 Chris Feist <cfeist@redhat.com> - 2.0.59-1
- New upstream sources
- Resolves: rhbz#222744 rhbz#222838 rhbz#222686  

* Mon Jan 15 2007 Chris Feist <cfeist@redhat.com> - 2.0.58-1
- New upstream sources
- Resolves: rhbz#221629  

* Thu Dec 21 2006 Chris Feist <cfeist@redhat.com> - 2.0.57-1
- New upstream sources
- Resolves: rhbz#218560  

* Mon Dec 18 2006 Chris Feist <cfeist@redhat.com> - 2.0.56-1
- New upstream sources.
- Resolves: rhbz#218551

* Mon Dec 18 2006 Chris Feist <cfeist@redhat.com> - 2.0.55-1
- New upstream sources.
- Resolves: rhbz#216954 rhbz#219878

* Fri Dec 15 2006 Chris Feist <cfeist@redhat.com> - 2.0.52-1
- New upstream sources.
- Resolves: rhbz#217724

* Thu Dec 14 2006 Chris Feist <cfeist@redhat.com> - 2.0.51-1
- New upstream sources.
- Resolves: rhbz#218688 rhbz#219385

* Tue Dec 05 2006 Chris Feist <cfeist@redhat.com> - 2.0.49-1
- New upstream sources.
- Resolves: rhbz#216052 rhbz#215962

* Tue Dec 05 2006 Chris Feist <cfeist@redhat.com> - 2.0.46-1
- New upstream sources.
- Resolves: rhbz#214540 rhbz#218103

* Wed Nov 29 2006 Chris Feist <cfeist@redhat.com> - 2.0.44-1
- New upstream sources.
- Resolves: rhbz#213878 rhbz#216902 rhbz#213763 rhbz#217436
- Resolves: rhbz#217460 rhbz#211836 rhbz#211918

* Mon Nov 13 2006 Chris Feist <cfeist@redhat.com> - 2.0.38-1
- New upstream sources with fixes for fence_xvmd (bz #212474)

* Thu Nov 09 2006 Chris Feist <cfeist@redhat.com> - 2.0.35-2
- New upstream sources with join_timeout and consensus_timeout
  set to high defaults (bz #214290)

* Mon Nov 06 2006 Chris Feist <cfeist@redhat.com> - 2.0.34-1
- New upstream sources.

* Fri Nov 03 2006 Chris Feist <cfeist@redhat.com> - 2.0.33-2
- New upstream sources.

* Fri Oct 27 2006 Chris Feist <cfeist@redaht.com> - 2.0.30-3
- Create and own /etc/cluster (bz #212582)

* Wed Oct 25 2006 Chris Feist <cfeist@redhat.com> - 2.0.30-1
- New upstream sources.

* Mon Oct 23 2006 Chris Feist <cfeist@redhat.com> - 2.0.29-1
- New upstream sources.

* Wed Oct 18 2006 Chris Feist <cfeist@redhat.com> - 2.0.28-4
- Build without xen deps.

* Mon Oct 16 2006 Chris Feist <cfeist@redhat.com> - 2.0.28-1
- New upstream sources

* Fri Oct 13 2006 Chris Feist <cfeist@redhat.com> - 2.0.25-1
- New upstream sources

* Thu Oct 12 2006 Chris Feist <cfeist@redhat.com> - 2.0.23-2
- New upstream sources
- Fixed init scripts

* Tue Oct 10 2006 Chris Feist <cfeist@redhat.com> - 2.0.22-1
- New upstream sources

* Thu Oct 5 2006 Chris Feist <cfeist@redhat.com> - 2.0.21-1
- New upstream sources
- Build w/ xen deps for fence-xen

* Sun Oct 01 2006 Jesse Keating <jkeating@redhat.com> - 2.0.18-2
- rebuilt for unwind info generation, broken in gcc-4.1.1-21

* Mon Sep 25 2006 Chris Feist <cfeist@redhat.com> - 2.0.18-1
- New upstream sources

* Tue Sep 19 2006 Chris Feist <cfeist@redhat.com> - 2.0.17-1
- New upstream sources

* Mon Sep 18 2006 Chris Feist <cfeist@redhat.com> - 2.0.16-1
- New upstream sources

* Thu Sep 14 2006 Chris Feist <cfeist@redhat.com> - 2.0.15-1
- New upstream sources

* Wed Sep 13 2006 Peter Jones <pjones@redhat.com> - 2.0.14-4
- Don't activate the service by default, since it won't be configured

* Wed Sep 13 2006 Chris Feist <cfeist@redhat.com> - 2.0.14-2
- Rebuild w/ new upstream sources
- Remove libxml deps

* Thu Aug 31 2006 Chris Feist <cfeist@redhat.com> - 2.0.13-1
- Rebuild w/ new upstream sources

* Fri Aug 25 2006 Chris Feist <cfeist@redhat.com> - 2.0.12-1
- Rebuild w/ new upstream sources

* Tue Aug 22 2006 Chris Feist <cfeist@redhat.com> - 2.0.11-1
- Rebuild w/ new upstream sources

* Wed Aug 16 2006 Chris Feist <cfeist@redhat.com> - 2.0.10-1
- Rebuild w/ new upstream sources

* Tue Aug 15 2006 Chris Feist <cfeist@redhat.com> - 2.0.9-0
- Rebuild w/ new upstream sources

* Fri Aug 11 2006 Chris Feist <cfeist@redhat.com> - 2.0.8-0
- Rebuild w/ new upstream sources

* Thu Aug 10 2006 Chris Feist <cfeist@redhat.com> - 2.0.7-0
- Rebuild w/ new upstream sources

* Wed Jul 12 2006 Jesse Keating <jkeating@redhat.com>
- rebuild

* Thu Jul 06 2006 Chris Feist <cfeist@redhat.com> - 2.0.1-0.fc6.0
- Rebuild w/ new upstream sources

* Wed Mar 01 2006 Chris Feist <cfeist@redhat.com> - 2.0.0-0.fc6.4
- Rebuilt w/ new upstream sources

* Tue Feb 07 2006 Jesse Keating <jkeating@redhat.com> - 1.0.4-0.FC5.1.1
- rebuilt for new gcc4.1 snapshot and glibc changes

* Fri Dec 16 2005 Chris Feist <cfeist@redhat.com>
- Rebuilt w/ new upstream sources

* Fri Dec 09 2005 Jesse Keating <jkeating@redhat.com>
- rebuilt

* Tue Jul 05 2005 Chris Feist <cfeist@redhat.com>
- Added libraries and cman-devel package

* Tue May 17 2005 Chris Feist <cfeist@redhat.com>
- Require cman-kernel-modules.

* Thu May 05 2005 Chris Feist <cfeist@redhat.com>
- Added patch to disable starting up the init scripts.

* Mon Dec 20 2004 Chris Feist <cfeist@redhat.com>
- Rebuild with new sources.

* Mon Dec 13 2004 Chris Feist <cfeist@redhat.com>
- Rebuild with new sources.

* Thu Nov 18 2004 Chris Feist <cfeist@redhat.com>
- various bug fixes (new upstream sources)

* Fri Oct 22 2004 Chris Feist <cfeist@redhat.com>
- various bug fixes (new upstream sources)

* Mon Aug 16 2004 Jon Brassow <jbrassow@redhat.com>
- update the requirements field

* Fri Aug 13 2004 Jon Brassow <jbrassow@redhat.com>
- various bug fixes (new upstream sources)
- add man pages

* Wed Jul 14 2004 Jon Brassow <jbrassow@redhat.com>
- build for i386 and x86_64 only

* Tue Jul 13 2004 Jon Brassow <jbrassow@redhat.com> 
- New upstream sources

* Thu Jun 17 2004 Jon Brassow <jbrassow@redhat.com> 
- Initial build.
